pub struct Item {
pub key: String,
pub value: Option<Box<Value>>,
}Expand description
An item in the store. The key must match the regex ^[A-z][A-z0-9_\.\/]{2,62}[A-z0-9]$. That
is, it must start with a letter, end with a letter or number, contain only letters, numbers,
periods, and slashes, and be between 4 and 64 characters long.
Fields
key: Stringvalue: Option<Box<Value>>Trait Implementations
Sourceimpl CompatFrom<Item> for Item
impl CompatFrom<Item> for Item
Sourcefn compat_from(value: Item) -> Item
fn compat_from(value: Item) -> Item
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<Item<'static>, ___E> for &'a Itemwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<Item<'static>, ___E> for &'a Itemwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourceimpl<___E> Encode<Item<'static>, ___E> for Itemwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<Item<'static>, ___E> for Itemwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourceimpl<'de> FromWireRef<Item<'de>> for Item
impl<'de> FromWireRef<Item<'de>> for Item
Sourcefn from_wire_ref(wire: &Item<'de>) -> Item
fn from_wire_ref(wire: &Item<'de>) -> Item
Converts the given reference to this type.
Sourceimpl Ord for Item
impl Ord for Item
Sourceimpl PartialOrd for Item
impl PartialOrd for Item
impl Eq for Item
impl StructuralPartialEq for Item